%define name	 ipython
%define version  2.3.0
%define release	 %mkrel 1
%define subrel  2

Summary:	 An interactive computing environment for Python 
Name:		 %{name}
Version:	 %{version}
Release:	 %{release}
Source0:	 http://pypi.python.org/packages/source/i/ipython/%{name}-%{version}.tar.gz
Patch0:        ipython-2.3.0-CVE-2015-4707.patch
Patch1:        ipython-2.3.0-mga16373.patch
Patch2:        ipython-2.3.0-mga16686.patch
License:	 BSD
Group:		 Development/Python
Url:		 http://ipython.org
BuildArch:	 noarch
Requires:      python-pexpect >= 2.2
Requires:      python-simplegeneric
Recommends:      python-mpi4py
Recommends:      wxPython, python-qt4, pyside >= 1.0.3
Recommends:      python-pygments 
Recommends:      python-pyzmq >= 2.1.11
#notebook requires tornado and jinja2
Recommends:      python-tornado >= 3.1 
Recommends:      python-jinja2
Recommends:      python-matplotlib
BuildRequires: python-devel
BuildRequires: python-simplegeneric
BuildRequires: python-setuptools
BuildRequires: python-pygments
BuildRequires: python-sphinx 
BuildRequires: python-jinja2
BuildRequires: python-pyzmq >= 2.1.11
BuildRequires: python-pexpect >= 2.2
BuildRequires: python-tornado >= 3.1 
BuildRequires: python-matplotlib
BuildRequires: python-numpydoc
# ovitters: pkgconfig(gobject-introspection-1.0) includes script to determine typelib() auto buildrequires
BuildRequires: pkgconfig(gobject-introspection-1.0)

%description
The goal of IPython is to create a comprehensive environment for
interactive and exploratory computing. To support this goal, IPython
has two main components:

* An enhanced interactive Python shell.
* An architecture for interactive parallel computing.

The enhanced interactive Python shell has the following main features:

* Comprehensive object introspection.
* Input history, persistent across sessions.
* Caching of output results during a session with automatically
  generated references.
* Readline based name completion.
* Extensible system of 'magic' commands for controlling the
  environment and performing many tasks related either to IPython or
  the operating system.
* Configuration system with easy switching between different setups
  (simpler than changing $PYTHONSTARTUP environment variables every
  time).
* Session logging and reloading.
* Extensible syntax processing for special purpose situations.
* Access to the system shell with user-extensible alias system.
* Easily embeddable in other Python programs and wxPython GUIs.
* Integrated access to the pdb debugger and the Python profiler.

The parallel computing architecture has the following main features:

* Quickly parallelize Python code from an interactive Python/IPython
  session.
* A flexible and dynamic process model that be deployed on anything
  from multicore workstations to supercomputers.
* An architecture that supports many different styles of parallelism,
  from message passing to task farming.
* Both blocking and fully asynchronous interfaces.
* High level APIs that enable many things to be parallelized in a few
  lines of code.
* Share live parallel jobs with other users securely.
* Dynamically load balanced task farming system.  
* Robust error handling in parallel code.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
# delete bundling libs
pushd IPython/external

# use decorators of numpy
rm decorators/_decorators.py

# other packages exist in Mageia
rm simplegeneric/_simplegeneric.py
rm pexpect/_pexpect.py

popd

# Get rid of library shebangs
find . -type f -name "*.py" -exec sed -i '/#!\/usr\/bin\/env/d' {} \;


%build
PYTHONDONTWRITEBYTECODE= %{__python} setup.py build

%install
%{__python} setup.py install -O1 --skip-build --root %{buildroot}
chmod 644 %{buildroot}%{_mandir}/man1/*.1*
find %{buildroot} -name .buildinfo -exec rm -f {} \;
find %{buildroot} -name .git_commit_info.ini -exec rm -rf {} \;

%files
%doc examples
%{_bindir}/*
%{python_sitelib}/*
%{_mandir}/man1/*


%changelog
* Wed Sep 02 2015 philippem <philippem> 2.3.0-1.2.mga4
+ Revision: 872301
- security fix from upstream mga#16686
- remove wrong requires on python-mglob, mga#16561
- fix mga#16373 with upstream patch and update to 2.3.0

  + luigiwalser <luigiwalser>
    - rediff upstream patch to fix CVE-2014-3429

* Tue Oct 22 2013 umeabot <umeabot> 1.1.0-3.mga4
+ Revision: 544806
- Mageia 4 Mass Rebuild

* Fri Oct 18 2013 malo <malo> 1.1.0-2.mga4
+ Revision: 519210
- fix suggests to jinja2 and tornado (patch by Daniel Napora)

* Tue Oct 15 2013 luigiwalser <luigiwalser> 1.1.0-1.mga4
+ Revision: 500286
- 1.1.0

* Mon Oct 14 2013 pterjan <pterjan> 1.0.0-2.mga4
+ Revision: 497820
- Rebuild to add different pythonegg provides for python 2 and 3

* Tue Aug 20 2013 luigiwalser <luigiwalser> 1.0.0-1.mga4
+ Revision: 468289
- 1.0.0

* Sun Aug 04 2013 joequant <joequant> 0.13.2-2.mga4
+ Revision: 463116
- redo spec
- suggest torando for ipython notebook

* Sun Apr 07 2013 luigiwalser <luigiwalser> 0.13.2-1.mga3
+ Revision: 408637
- 0.13.2

* Sat Jan 12 2013 umeabot <umeabot> 0.13.1-2.mga3
+ Revision: 354491
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 03 2013 luigiwalser <luigiwalser> 0.13.1-1.mga3
+ Revision: 338399
- 0.13.1

* Mon Oct 22 2012 dams <dams> 0.13-1.mga3
+ Revision: 309263
- new version 0.13

* Tue Sep 20 2011 lebedov <lebedov> 0.11-2.mga2
+ Revision: 146101
- Update to 0.11.

* Thu Apr 21 2011 ahmad <ahmad> 0.10.2-1.mga1
+ Revision: 89370
- Update to 0.10.2
- Drop patch0, redundant now that man pages get compressed properl without it
- Replace the deprecated %%py_requires macro with BR python-devel
- Use the upstream %%{python_sitelib} macro
- Don't copy REAME.txt manually, %%doc it instead

* Sun Mar 06 2011 saispo <saispo> 0.10.1-1.mga1
+ Revision: 65239
- imported package ipython

